@@ -1,8 +1,7 @@
-from __future__ import with_statement
 import os
 from pprint import pprint
 
-from paver.deps.six import print_
+from six import exec_, PY2, print_
 
 from paver import setuputils, misctasks, tasks, options
 
@@ -635,8 +634,8 @@ class MyTaskFinder(object):
         return None
         
     def get_tasks(self):
-        return set([self.foo])
-    
+        return {self.foo}
+
     @tasks.task
     def foo(self):
         self.foo_called = True
@@ -847,6 +846,25 @@ def test_calling_task_with_arguments():
 
     tasks._process_commands(['t1'])
 
+def test_calling_task_with_empty_arguments():
+    @tasks.task
+    def t1():
+        env.call_task('t3', args=['argument1'])
+        env.call_task('t2', args=[])
+
+    @tasks.task
+    @tasks.consume_args
+    def t2(args):
+        assert args == []
+
+    @tasks.task
+    @tasks.consume_args
+    def t3(args):
+        assert args == ['argument1']
+
+    env = _set_environment(t1=t1, t2=t2, t3=t3)
+    tasks._process_commands(['t1'])
+
 def test_calling_nonconsuming_task_with_arguments():
     @tasks.task
     def t2():
@@ -915,3 +933,24 @@ def test_options_might_be_shared_both_way():
 
     assert t1.called
     assert t2.called
+
+
+if not PY2:
+    def test_paver_doesnt_crash_on_task_function_with_annotations():
+        local_scope = {}
+        # exec()ing so that it doesn't crash when this test file is run
+        # under Python 2 which doesn't support this syntax
+        exec_(
+            """
+@tasks.task
+def fun() -> None:
+    pass""",
+            globals(), local_scope,
+        )
+        fun = local_scope['fun']
+        environment = _set_environment(fun=fun)
+
+        # This call would fail with:
+        #     ValueError: Function has keyword-only arguments or annotations,
+        #     use getfullargspec() API which can support them
+        fun()
